# Evolutionary algorithms in (pure) Python

There are three algorithms implemented in this package (from best to worse):

- epso (Evolutionary Particle Swarm Optimization)
- pso (Particle Swarm Optimization) (tbd)
- pop (Classic Genetic Algorithm) (tbd)
